@@ -6,8 +6,8 @@
 //! invocation of this macro as multiple parameters.
 //!
 //! **You cannot invoke this macro more than once in a given scope.**
-//! This is because its implementation is based on a type synonym definition and
-//! two or more invocation causes name collision.
+//! This is because its implementation is based on a function definition and
+//! two or more invocations cause name collision.
 //!
 //! ## Example
 //! ```
@@ -25,7 +25,7 @@
 #[macro_export]
 macro_rules! static_assert {
     (let $e:expr; ) => (
-        type _ArrayForStaticAssert = [i8; ($e) as usize - 1];
+        fn _fn_for_static_assert(_: [i8; ($e) as usize - 1]) {}
     );
 
     (let $e:expr; $e1:expr $(, $ee:expr)*) => (
@@ -39,18 +39,35 @@ macro_rules! static_assert {
 
 #[cfg(test)]
 mod tests {
+    #[test]
+    fn test_simple() {
+        static_assert!(true);
+    }
+
+    #[test]
+    fn test_simple_failure() {
+        // static_assert!(false); // should not compile
+    }
+
     const _FOUR: i32 = 4;
 
     #[test]
-    fn test_0() {
-        static_assert!(1 + 2 == { _FOUR - 1 }, 2 < 3);
+    fn test_const_arithmetic() {
+        static_assert!(1 + 2 == { _FOUR - 1 });
     }
+
     #[test]
-    fn test_1() {
-        static_assert!(true);
+    fn test_multiple_asserts() {
+        static_assert!(0 < 1, 1 < 2, 2 < 3);
     }
+
     #[test]
-    fn test_2() {
+    fn test_failure_in_multiple_asserts() {
+        // static_assert!(0 < 1, 9999 < 2, 2 < 3); // should not compile
+    }
+
+    #[test]
+    fn test_integral_args_are_not_supported() {
         // static_assert!(1); // should not compile
     }
 }
